Pyruvate dehydrogenase (quinone) - Wikipedia

Jump to content

# Pyruvate dehydrogenase (quinone)

5 languages

- Español
- Français
- 日本語
- Српски / srpski
- Srpskohrvatski / српскохрватски

Edit links
From Wikipedia, the free encyclopedia

Pyruvate dehydrogenase (quinone)
Identifiers
EC no. | 1.2.5.1
Databases
IntEnz | IntEnz view
BRENDA | BRENDA entry
ExPASy | NiceZyme view
KEGG | KEGG entry
MetaCyc | metabolic pathway
PRIAM | profile
PDB structures | RCSB PDB PDBe PDBsum
Search
PMC | articles
PubMed | articles
NCBI | proteins

Pyruvate dehydrogenase (quinone) (EC 1.2.5.1, pyruvate dehydrogenase, pyruvic dehydrogenase, pyruvic (cytochrome b1) dehydrogenase, pyruvate:ubiquinone-8-oxidoreductase, pyruvate oxidase (ambiguous)) is an enzyme with systematic name pyruvate:ubiquinone oxidoreductase.[1][2][3][4][5][6][7][8] This enzyme catalyses the following chemical reaction

  pyruvate + ubiquinone + H2O ⇌ {\displaystyle \rightleftharpoons } acetate + CO2 + ubiquinol

This bacterial enzyme is located on the inner surface of the cytoplasmic membrane.

## References

[edit]

1. ^
   Recny MA, Hager LP (November 1982). "Reconstitution of native Escherichia coli pyruvate oxidase from apoenzyme monomers and FAD". The Journal of Biological Chemistry. 257 (21): 12878–86. PMID 6752142.
2. ^ Cunningham CC, Hager LP (September 1975). "Reactivation of the lipid-depleted pyruvate oxidase system from Escherichia coli with cell envelope neutral lipids". The Journal of Biological Chemistry. 250 (18): 7139–46. PMID 1100621.
3. ^ Koland JG, Miller MJ, Gennis RB (January 1984). "Reconstitution of the membrane-bound, ubiquinone-dependent pyruvate oxidase respiratory chain of Escherichia coli with the cytochrome d terminal oxidase". Biochemistry. 23 (3): 445–53. doi:10.1021/bi00298a008. PMID 6367818.
4. ^ Grabau C, Cronan JE (July 1986). "In vivo function of Escherichia coli pyruvate oxidase specifically requires a functional lipid binding site". Biochemistry. 25 (13): 3748–51. doi:10.1021/bi00361a003. PMID 3527254.
5. ^ Wang AY, Chang YY, Cronan JE (June 1991). "Role of the tetrameric structure of Escherichia coli pyruvate oxidase in enzyme activation and lipid binding". The Journal of Biological Chemistry. 266 (17): 10959–66. PMID 2040613.
6. ^ Chang YY, Cronan JE (September 1997). "Sulfhydryl chemistry detects three conformations of the lipid binding region of Escherichia coli pyruvate oxidase". Biochemistry. 36 (39): 11564–73. doi:10.1021/bi9709102. PMID 9305946.
7. ^ O'Brien TA, Schrock HL, Russell P, Blake R, Gennis RB (November 1976). "Preparation of Escherichia coli pyruvate oxidase utilizing a thiamine pyrophosphate affinity column". Biochimica et Biophysica Acta (BBA) - Enzymology. 452 (1): 13–29. doi:10.1016/0005-2744(76)90054-1. PMID 791368.
8. ^ Bertagnolli BL, Hager LP (January 1993). "Role of flavin in acetoin production by two bacterial pyruvate oxidases". Archives of Biochemistry and Biophysics. 300 (1): 364–71. doi:10.1006/abbi.1993.1049. PMID 8424670.

## External links

[edit]

- Pyruvate+dehydrogenase+(quinone) at the U.S. National Library of Medicine Medical Subject Headings (MeSH)

Retrieved from "https://en.wikipedia.org/w/index.php?title=Pyruvate_dehydrogenase_(quinone)&oldid=1172359379"
Category:

- EC 1.2.5